@@ -16,7 +16,7 @@ import os
 import re
 import logging
 
-__version__ = '1.10.35'
+__version__ = '1.10.45'
 
 
 class NullHandler(logging.Handler):
@@ -55,6 +55,8 @@ _xform_cache = {
 _partial_renames = {
     'ipv-6': 'ipv6',
     'ipv_6': 'ipv6',
+    's_3_resources': 's3_resources',
+    's-3-resources': 's3-resources',
 }
 ScalarTypes = ('string', 'integer', 'boolean', 'timestamp', 'float', 'double')
 
